@@ -13,7 +13,7 @@
 
 package IO::Socket::SSL;
 
-our $VERSION = '2.034';
+our $VERSION = '2.035';
 
 use IO::Socket;
 use Net::SSLeay 1.46;
@@ -582,7 +582,8 @@ sub configure_SSL {
     $FILTER_SSL_ARGS->($is_server,$arg_hash) if $FILTER_SSL_ARGS;
 
     # this adds defaults to $arg_hash as a side effect!
-    ${*$self}{'_SSL_ctx'} = IO::Socket::SSL::SSL_Context->new($arg_hash);
+    ${*$self}{'_SSL_ctx'} = IO::Socket::SSL::SSL_Context->new($arg_hash)
+	or return;
 
     ${*$self}{'_SSL_arguments'} = $arg_hash;
     ${*$self}{'_SSL_opened'} = 1 if $is_server;
@@ -2127,12 +2128,9 @@ sub new {
     my $arg_hash = (ref($_[0]) eq 'HASH') ? $_[0] : {@_};
 
     my $is_server = $arg_hash->{SSL_server};
-    my %defaults = (
-	%$GLOBAL_SSL_ARGS,
-	$is_server 
-	    ? (%$GLOBAL_SSL_SERVER_ARGS, %DEFAULT_SSL_SERVER_ARGS) 
-	    : (%$GLOBAL_SSL_CLIENT_ARGS, %DEFAULT_SSL_CLIENT_ARGS),
-    );
+    my %defaults = $is_server
+	? (%DEFAULT_SSL_SERVER_ARGS, %$GLOBAL_SSL_ARGS, %$GLOBAL_SSL_SERVER_ARGS) 
+	: (%DEFAULT_SSL_CLIENT_ARGS, %$GLOBAL_SSL_ARGS, %$GLOBAL_SSL_CLIENT_ARGS);
     if ( $defaults{SSL_reuse_ctx} ) {
 	# ignore default context if there are args to override it
 	delete $defaults{SSL_reuse_ctx}
